@@ -4,7 +4,7 @@
 #include <apt-pkg/indexfile.h>
 #include <apt-pkg/init.h>
 
-#include <stddef.h>
+#include <cstddef>
 
 #include <string>
 #include <vector>
@@ -17,7 +17,7 @@ class OpProgress;
 
 class metaIndexPrivate;
 
-class metaIndex
+class APT_PUBLIC metaIndex
 {
 public:
    struct checkSum
@@ -30,7 +30,13 @@ public:
    enum APT_HIDDEN TriState {
       TRI_YES, TRI_DONTCARE, TRI_NO, TRI_UNSET
    };
-private:
+
+   enum class APT_HIDDEN Flag
+   {
+      DEB822 = 0x01,
+   };
+
+   private:
    metaIndexPrivate * const d;
 protected:
    std::vector <pkgIndexFile *> *Indexes;
@@ -44,6 +50,11 @@ protected:
    // parsed from a file
    std::string Suite;
    std::string Codename;
+   std::string Origin;
+   std::string Label;
+   std::string Version;
+   signed short DefaultPin;
+   std::string ReleaseNotes;
    time_t Date;
    time_t ValidUntil;
    bool SupportsAcquireByHash;
@@ -68,7 +79,11 @@ public:
    bool GetSupportsAcquireByHash() const;
    time_t GetValidUntil() const;
    time_t GetDate() const;
-   APT_HIDDEN time_t GetNotBefore() const; // FIXME make virtual
+   virtual time_t GetNotBefore() const = 0;
+#ifdef APT_COMPILING_APT
+   bool HasFlag(Flag flag) const;
+#endif
+   void SetFlag(Flag flag) APT_HIDDEN;
 
    std::string GetExpectedDist() const;
    bool CheckDist(std::string const &MaybeDist) const;
@@ -81,6 +96,7 @@ public:
    virtual std::vector<pkgIndexFile *> *GetIndexFiles() = 0;
    virtual bool IsTrusted() const = 0;
    virtual bool Load(std::string const &Filename, std::string * const ErrorText) = 0;
+   bool Load(std::string *const ErrorText);
    /** @return a new metaIndex object based on this one, but without information from #Load */
    virtual metaIndex * UnloadedClone() const = 0;
    // the given metaIndex is potentially invalid after this call and should be deleted
@@ -102,16 +118,13 @@ public:
              char const * const Type);
    virtual ~metaIndex();
 
-   // FIXME: make virtual on next abi break
-   bool IsArchitectureSupported(std::string const &arch) const;
-   bool IsArchitectureAllSupportedFor(IndexTarget const &target) const;
-   bool HasSupportForComponent(std::string const &component) const;
-   // FIXME: should be members of the class on abi break
-   APT_HIDDEN void SetOrigin(std::string const &origin);
-   APT_HIDDEN void SetLabel(std::string const &label);
-   APT_HIDDEN void SetVersion(std::string const &version);
-   APT_HIDDEN void SetDefaultPin(signed short const defaultpin);
-   APT_HIDDEN void SetReleaseNotes(std::string const &notes);
+   virtual bool IsArchitectureSupported(std::string const &arch) const;
+   virtual bool IsArchitectureAllSupportedFor(IndexTarget const &target) const;
+   virtual bool HasSupportForComponent(std::string const &component) const;
+
+#ifdef APT_COMPILING_APT
+   bool IsTrustedSet() { return Trusted == TRI_YES; }
+#endif
 };
 
 #endif
